/**
*@ author Sebastian Seyrich, Markus Mattes
*/

import java.awt.*;
import java.awt.event.*;

public class ColumnComponent extends AnotherCanvas implements MouseListener{
    
    private boolean mouseEntered;
    private int diameter;//size of the chips
    private int space;//distance between the chips
    private ClientPanel clientPanel;
    private int[] column;
    private int columnNumber;
    private Dimension dim;
    private Color emptyColor;
    private Color myColor;
    private Color opponentColor;
    private Color componentColor;
    private Color componentColor2; 
    private boolean isActive;
    
	
    
    public ColumnComponent(int _columnNumber,ClientPanel _clientPanel, int sizeFactor){
		super();
		clientPanel = _clientPanel;
		columnNumber = _columnNumber;
		
		column = new int[6];
		addMouseListener(this);
		int width = sizeFactor;
		diameter = (int)(width*0.64);
		space = (int)((width-diameter)/2);
		int height =( 6*(width-space))+space;
		dim = new Dimension(width,height);
		emptyColor = Color.white;
		myColor = Color.yellow;
		opponentColor = Color.green; 
		componentColor = (new Color(102,114,253)).darker();
		componentColor2 = new Color(102,114,253);	
		isActive = false;
		setEnabled(isActive);
		setSize(dim);
    }

    /**
     *Passes this row a new state
     *Component will be redrawn
     */
    public void setColumn(int[] _column){
		column = _column;
		repaint();
    }

    /**
     *true: Activates the component 
 	 *Turn can be checked	
     *false: Deactivates the component, so no reaction for mouseevents 
     */
    public void setActive(boolean b){
		isActive = b;
		setEnabled(isActive);
    }
    
    
    public int[] getColumn(){
		return column;
    }
    
    public void paint(Graphics g){
    	if(!mouseEntered)
    	   g.setColor(componentColor);
    	else
    	   g.setColor(componentColor.brighter());
    	//the whole surface
    	g.fillRect(0,0,dim.width,dim.height);
    	if(!mouseEntered)
    		g.setColor(componentColor2);
    	else
    		g.setColor(componentColor2.darker());
    	//the inner surface
    	g.fillRoundRect(space/2,space/2,diameter+space,dim.height-space,(diameter+space)/2,(diameter+space)/2);
    	for(int i=0;i<column.length;i++){
    		if(!mouseEntered)
    			g.setColor(componentColor);
    		else
    			g.setColor(componentColor.brighter());
    		//area around the chips
    		g.fillRoundRect(space,dim.height-(i+1)*(diameter+space),diameter,diameter,10,10);
    		if(column[i]==0)
    			g.setColor(emptyColor);
    		if(column[i]==1)
    			g.setColor(myColor);
    		if(column[i]==2)
    			g.setColor(opponentColor);
			
    		//the circles
    		g.fillOval(space,dim.height-(i+1)*(diameter+space),diameter,diameter);
    	}
    }
    
    /**
     *layoutmanager shoul not shrink the surrounding container
     *to size 0x0
     */
    public Dimension getMaximumSize(){
		return dim;
    }
    public Dimension getMinimumSize(){
		return dim;
    } 
    public Dimension getPreferredSizeSize(){
		return dim;
    } 
    
    
    public void mousePressed(MouseEvent e){
		//System.out.println("In ColumnComponente"+columnNumber+" mousePressed");
    }
    public void mouseReleased(MouseEvent e){
		//System.out.println("In ColumnComponente"+columnNumber+" mouseReleased");
	
    }
    public void mouseClicked(MouseEvent e){
		//System.out.println("In ColumnComponente"+columnNumber+" mouseClicked");
		if(isActive){
		    isActive=false;
		    setEnabled(isActive);
		    clientPanel.makeYourChoice(columnNumber);
		    repaint();
	}
    }
	public void mouseEntered(MouseEvent e){
	    mouseEntered = true;
	    repaint();
	    //System.out.println("In ColumnComponente"+columnNumber+" mouseEntered");
	}
    public void mouseExited(MouseEvent e){
		mouseEntered = false;
		repaint();
		//System.out.println("In ColumnComponente"+columnNumber+" mouseExited");
    }
    

    
    
    
}